summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteglobal.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteglobal.h')
-rw-r--r--kopete/libkopete/kopeteglobal.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kopete/libkopete/kopeteglobal.h b/kopete/libkopete/kopeteglobal.h
index aa6456f4..395d0eae 100644
--- a/kopete/libkopete/kopeteglobal.h
+++ b/kopete/libkopete/kopeteglobal.h
@@ -47,7 +47,7 @@ namespace Global
*
* TODO: If possible, port it to KIO instead of using ugly blocking KTar
**/
- KOPETE_EXPORT void installEmoticonTheme(const QString &localPath);
+ KOPETE_EXPORT void installEmoticonTheme(const TQString &localPath);
/**
* \brief Global facility to query/store templates that are needed by KopeteContactProperty
@@ -72,7 +72,7 @@ namespace Global
* Return a template with defined by @p key, if no such template has
* been registered ContactPropertyTmpl::null will be returned
*/
- const ContactPropertyTmpl &tmpl(const QString &key) const;
+ const ContactPropertyTmpl &tmpl(const TQString &key) const;
/**
* @return a ready-to-use template for a contact's full name.
@@ -135,8 +135,8 @@ namespace Global
/**
* default template for a contact's photo.
*
* It could be either a QString or a QImage.
* If it's a QString, it should points to the path the image is stored.
*/
const ContactPropertyTmpl &photo() const;
@@ -149,18 +149,18 @@ namespace Global
* return true if a template with key @p key is already registered,
* false otherwise
*/
- bool isRegistered(const QString &key);
+ bool isRegistered(const TQString &key);
private:
Properties();
~Properties();
- bool registerTemplate(const QString &key,
+ bool registerTemplate(const TQString &key,
const ContactPropertyTmpl &tmpl);
- void unregisterTemplate(const QString &key);
+ void unregisterTemplate(const TQString &key);
- const ContactPropertyTmpl &createProp(const QString &key,
- const QString &label, const QString &icon=QString::null,
+ const ContactPropertyTmpl &createProp(const TQString &key,
+ const TQString &label, const TQString &icon=TQString::null,
bool persistent = false) const;
private:
@@ -135,8 +135,8 @@ namespace Global
* default template for a contact's photo.
*
- * It could be either a QString or a QImage.
- * If it's a QString, it should points to the path the image is stored.
+ * It could be either a TQString or a TQImage.
+ * If it's a TQString, it should points to the path the image is stored.
*/
const ContactPropertyTmpl &photo() const;